@@ -24,9 +24,13 @@
  */
 
 #include "createdialog.h"
-#include "mimetypes.h"
+#include "pluginmanager.h"
+
+#include <KCollapsibleGroupBox>
 
 #include <QCheckBox>
+#include <QComboBox>
+#include <QLineEdit>
 #include <QMimeDatabase>
 #include <QTest>
 
@@ -37,12 +41,78 @@ class CreateDialogTest : public QObject
     Q_OBJECT
 
 private Q_SLOTS:
-
+    void testBasicWidgets_data();
+    void testBasicWidgets();
     void testEncryption_data();
     void testEncryption();
     void testHeaderEncryptionTooltip();
+
+private:
+    PluginManager m_pluginManager;
 };
 
+void CreateDialogTest::testBasicWidgets_data()
+{
+    QTest::addColumn<QString>("mimeType");
+
+    QTest::newRow("tar") << QStringLiteral("application/x-tar");
+    QTest::newRow("targzip") << QStringLiteral("application/x-compressed-tar");
+    QTest::newRow("tarbzip") << QStringLiteral("application/x-bzip-compressed-tar");
+    QTest::newRow("tarZ") << QStringLiteral("application/x-tarz");
+    QTest::newRow("tarxz") << QStringLiteral("application/x-xz-compressed-tar");
+    QTest::newRow("tarlzma") << QStringLiteral("application/x-lzma-compressed-tar");
+    QTest::newRow("tarlzop") << QStringLiteral("application/x-tzo");
+    QTest::newRow("tarlzip") << QStringLiteral("application/x-lzip-compressed-tar");
+
+    const auto writeMimeTypes = m_pluginManager.supportedWriteMimeTypes();
+
+    if (writeMimeTypes.contains(QStringLiteral("application/zip"))) {
+        QTest::newRow("zip") << QStringLiteral("application/zip");
+    } else {
+        qDebug() << "zip format not available in CreateDialog, skipping test.";
+    }
+
+    if (writeMimeTypes.contains(QStringLiteral("application/x-7z-compressed"))) {
+        QTest::newRow("7z") << QStringLiteral("application/x-7z-compressed");
+    } else {
+        qDebug() << "7z format not available in CreateDialog, skipping test.";
+    }
+
+    if (writeMimeTypes.contains(QStringLiteral("application/x-rar"))) {
+        QTest::newRow("rar") << QStringLiteral("application/x-rar");
+    } else {
+        qDebug() << "rar format not available in CreateDialog, skipping test.";
+    }
+
+    if (writeMimeTypes.contains(QStringLiteral("application/x-lrzip-compressed-tar"))) {
+        QTest::newRow("tarlrzip") << QStringLiteral("application/x-lrzip-compressed-tar");
+    } else {
+        qDebug() << "tar.lrzip format not available in CreateDialog, skipping test.";
+    }
+}
+
+void CreateDialogTest::testBasicWidgets()
+{
+    CreateDialog *dialog = new CreateDialog(Q_NULLPTR, QString(), QUrl());
+
+    auto fileNameLineEdit = dialog->findChild<QLineEdit*>(QStringLiteral("filenameLineEdit"));
+    auto archiveTypeComboBox = dialog->findChild<QComboBox*>(QStringLiteral("mimeComboBox"));
+    QVERIFY(fileNameLineEdit);
+    QVERIFY(archiveTypeComboBox);
+
+    QFETCH(QString, mimeType);
+    const QMimeType mime = QMimeDatabase().mimeTypeForName(mimeType);
+
+    // Test if combobox is updated when user enters a filename with suffix.
+    fileNameLineEdit->setText(QStringLiteral("basename.%1").arg(mime.preferredSuffix()));
+    QCOMPARE(archiveTypeComboBox->currentText(), mime.comment());
+
+    // Test if suffix is added correctly when the user selects an archive type in combobox.
+    fileNameLineEdit->setText(QStringLiteral("basename"));
+    archiveTypeComboBox->setCurrentText(mime.comment());
+    QCOMPARE(QFileInfo(dialog->selectedUrl().toLocalFile()).fileName(), QStringLiteral("basename.%1").arg(mime.preferredSuffix()));
+}
+
 void CreateDialogTest::testEncryption_data()
 {
     QTest::addColumn<QString>("filter");
@@ -51,19 +121,19 @@ void CreateDialogTest::testEncryption_data()
 
     QTest::newRow("tar") << QStringLiteral("application/x-compressed-tar") << false << false;
 
-    if (Kerfuffle::supportedWriteMimeTypes().contains(QStringLiteral("application/zip"))) {
+    if (m_pluginManager.supportedWriteMimeTypes().contains(QStringLiteral("application/zip"))) {
         QTest::newRow("zip") << QStringLiteral("application/zip") << true << false;
     } else {
         qDebug() << "zip format not available in CreateDialog, skipping test.";
     }
 
-    if (Kerfuffle::supportedWriteMimeTypes().contains(QStringLiteral("application/x-7z-compressed"))) {
+    if (m_pluginManager.supportedWriteMimeTypes().contains(QStringLiteral("application/x-7z-compressed"))) {
         QTest::newRow("7z") << QStringLiteral("application/x-7z-compressed") << true << true;
     } else {
         qDebug() << "7z format not available in CreateDialog, skipping test.";
     }
 
-    if (Kerfuffle::supportedWriteMimeTypes().contains(QStringLiteral("application/x-rar"))) {
+    if (m_pluginManager.supportedWriteMimeTypes().contains(QStringLiteral("application/x-rar"))) {
         QTest::newRow("rar") << QStringLiteral("application/x-rar") << true << true;
     } else {
         qDebug() << "rar format not available in CreateDialog, skipping test.";
@@ -78,12 +148,12 @@ void CreateDialogTest::testEncryption()
     QFETCH(bool, isEncryptionAvailable);
     QFETCH(bool, isHeaderEncryptionAvailable);
 
-    auto encryptCheckBox = dialog->findChild<QCheckBox*>(QStringLiteral("encryptCheckBox"));
+    auto collapsibleEncryption = dialog->findChild<KCollapsibleGroupBox*>(QStringLiteral("collapsibleEncryption"));
     auto encryptHeaderCheckBox = dialog->findChild<QCheckBox*>(QStringLiteral("encryptHeaderCheckBox"));
-    QVERIFY(encryptCheckBox);
+    QVERIFY(collapsibleEncryption);
     QVERIFY(encryptHeaderCheckBox);
 
-    dialog->setCurrentFilterFromMimeType(filter);
+    QVERIFY(dialog->setMimeType(filter));
 
     // Encryption is initially not enabled.
     QVERIFY(!dialog->isEncryptionEnabled());
@@ -92,7 +162,7 @@ void CreateDialogTest::testEncryption()
     if (isEncryptionAvailable) {
         QVERIFY(dialog->isEncryptionAvailable());
 
-        encryptCheckBox->setChecked(true);
+        collapsibleEncryption->setExpanded(true);
         QVERIFY(dialog->isEncryptionEnabled());
 
         if (isHeaderEncryptionAvailable) {
@@ -106,7 +176,7 @@ void CreateDialogTest::testEncryption()
             QVERIFY(!dialog->isHeaderEncryptionAvailable());
         }
 
-        encryptCheckBox->setChecked(false);
+        collapsibleEncryption->setExpanded(false);
         QVERIFY(!dialog->isEncryptionEnabled());
         QVERIFY(!dialog->isHeaderEncryptionEnabled());
     } else {
@@ -119,24 +189,24 @@ void CreateDialogTest::testEncryption()
 
 void CreateDialogTest::testHeaderEncryptionTooltip()
 {
-    if (!Kerfuffle::supportedWriteMimeTypes().contains(QStringLiteral("application/zip"))) {
+    if (!m_pluginManager.supportedWriteMimeTypes().contains(QStringLiteral("application/zip"))) {
         QSKIP("zip format not available in CreateDialog, skipping test.", SkipSingle);
     }
 
     CreateDialog *dialog = new CreateDialog(Q_NULLPTR, QString(), QUrl());
 
-    auto encryptCheckBox = dialog->findChild<QCheckBox*>(QStringLiteral("encryptCheckBox"));
+    auto collapsibleEncryption = dialog->findChild<KCollapsibleGroupBox*>(QStringLiteral("collapsibleEncryption"));
     auto encryptHeaderCheckBox = dialog->findChild<QCheckBox*>(QStringLiteral("encryptHeaderCheckBox"));
-    QVERIFY(encryptCheckBox);
+    QVERIFY(collapsibleEncryption);
     QVERIFY(encryptHeaderCheckBox);
 
-    encryptCheckBox->setChecked(true);
+    collapsibleEncryption->setExpanded(true);
 
-    dialog->setCurrentFilterFromMimeType(QStringLiteral("application/zip"));
+    QVERIFY(dialog->setMimeType(QStringLiteral("application/zip")));
     QVERIFY(!encryptHeaderCheckBox->toolTip().isEmpty());
 
     // If we set a tar filter after the zip one, ensure that the old zip's tooltip is not shown anymore.
-    dialog->setCurrentFilterFromMimeType(QStringLiteral("application/x-compressed-tar"));
+    QVERIFY(dialog->setMimeType(QStringLiteral("application/x-compressed-tar")));
     QVERIFY(encryptHeaderCheckBox->toolTip().isEmpty());
 }
 
