@@ -171,6 +171,8 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList& args)
             this, static_cast<void (Part::*)(const QStringList&, const QString&)>(&Part::slotAddFiles));
     connect(m_model, &ArchiveModel::error,
             this, &Part::slotError);
+    connect(m_model, &ArchiveModel::messageWidget,
+            this, &Part::displayMsgWidget);
 
     connect(this, &Part::busy,
             this, &Part::setBusyGui);
@@ -186,7 +188,7 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList& args)
 
 Part::~Part()
 {
-    qDeleteAll(m_tmpOpenDirList);
+    qDeleteAll(m_tmpExtractDirList);
 
     // Only save splitterSizes if infopanel is visible,
     // because we don't want to store zero size for infopanel.
@@ -367,6 +369,7 @@ void Part::setupActions()
     m_addFilesAction->setIcon(QIcon::fromTheme(QStringLiteral("archive-insert")));
     m_addFilesAction->setText(i18n("Add &Files..."));
     m_addFilesAction->setToolTip(i18nc("@info:tooltip", "Click to add files to the archive"));
+    actionCollection()->setDefaultShortcut(m_addFilesAction, Qt::ALT + Qt::Key_A);
     connect(m_addFilesAction, SIGNAL(triggered(bool)),
             this, SLOT(slotAddFiles()));
 
@@ -409,8 +412,7 @@ void Part::setupActions()
 
 void Part::updateActions()
 {
-    bool isWritable = m_model->archive() && !m_model->archive()->isReadOnly() &&
-                      !(m_model->rowCount() > 0 && m_model->archive()->isMultiVolume());
+    bool isWritable = m_model->archive() && !m_model->archive()->isReadOnly();
     bool isDirectory = m_model->entryForIndex(m_view->selectionModel()->currentIndex())[IsDirectory].toBool();
     int selectedEntriesCount = m_view->selectionModel()->selectedRows().count();
 
@@ -618,8 +620,7 @@ void Part::slotQuickExtractFiles(QAction *triggeredAction)
 
         Kerfuffle::ExtractionOptions options;
         options[QStringLiteral("PreservePaths")] = true;
-        QList<QVariant> files = filesAndRootNodesForIndexes(m_view->selectionModel()->selectedRows());
-        ExtractJob *job = m_model->extractFiles(files, finalDestinationDirectory, options);
+        ExtractJob *job = m_model->extractFiles(filesAndRootNodesForIndexes(addChildren(m_view->selectionModel()->selectedRows())), finalDestinationDirectory, options);
         registerJob(job);
 
         connect(job, &KJob::result,
@@ -919,7 +920,7 @@ void Part::slotOpenExtractedEntry(KJob *job)
 
         // Since the user could modify the file (unlike the Preview case),
         // we'll need to manually delete the temp dir in the Part destructor.
-        m_tmpOpenDirList << openJob->tempDir();
+        m_tmpExtractDirList << openJob->tempDir();
 
         const QString fullName = openJob->validatedFilePath();
 
@@ -957,6 +958,7 @@ void Part::slotPreviewExtractedEntry(KJob *job)
         PreviewJob *previewJob = qobject_cast<PreviewJob*>(job);
         Q_ASSERT(previewJob);
 
+        m_tmpExtractDirList << previewJob->tempDir();
         ArkViewer::view(previewJob->validatedFilePath());
 
     } else if (job->error() != KJob::KilledJobError) {
@@ -971,7 +973,7 @@ void Part::slotWatchedFileModified(const QString& file)
 
     // Find the relative path of the file within the archive.
     QString relPath = file;
-    foreach (QTemporaryDir *tmpDir, m_tmpOpenDirList) {
+    foreach (QTemporaryDir *tmpDir, m_tmpExtractDirList) {
         relPath.remove(tmpDir->path()); //Remove tmpDir.
     }
     relPath = relPath.mid(1); //Remove leading slash.
